@@ -30,7 +30,7 @@ import requests
 # are processed.
 #
 # This is supported in Python 3.7+
-from .exceptions import AnamlError
+from .exceptions import AnamlError, Reason
 from .models.summary_statistics import SummaryStatistics
 
 if typing.TYPE_CHECKING:
@@ -978,18 +978,22 @@ class Anaml:
             try:
                 result = r.json()
                 return result
-            except json.JSONDecodeError:
+            except json.decoder.JSONDecodeError:
                 # Sorry, (no or invalid) JSON here
                 self._log.error("No or invalid JSON received from server")
                 self._log.error("Response content: " + r.text)
-                r.raise_for_status()
+                raise AnamlError(errors=[Reason(message="Expected JSON but the server did not return any")])
         else:
-            response_json = r.json()
-            if "errors" in response_json:
-                ex = AnamlError.from_json(response_json)
-                self._log.error("The Anaml server reported an error", ex)
-                raise ex
-        r.raise_for_status()
+            try:
+                response_json = r.json()
+                if "errors" in response_json:
+                    ex = AnamlError.from_json(response_json)
+                    self._log.error("The Anaml server reported an error", ex)
+                    raise ex
+            except json.decoder.JSONDecodeError:
+                # This is not unexpected. 404 responses, in particular, often have no JSON error message.
+                pass
+            r.raise_for_status()
 
     def _int_or_handle_errors(self, r):
         if r.ok:
